/* LOCKVC Version 3.6 (c) 1994,1995,1997 by Matthias Straub */
/* shadow-password option added by Ed Beaumont */
/* this file was released under GPL */
/* see COPYING for details */
/* Thanks to <unknown> for the Linux-Shark picture */ 

#include <vga.h>
#include <stdio.h>
#include <math.h>

#include "lockvc.h"

struct vars 
{
char *lbuffer;
unsigned char *screen;
unsigned char *rscreen;
int xoff[200];
int yoff[320];
};

void draw_fudge(struct vars *this)
     {
	#include "bild.fudge"
	unsigned char *lscreen;
	int x,y;
	int checkx,checky;

	x=0;y=0;
	this->lbuffer=buffer;
	for(lscreen=this->rscreen;lscreen<this->rscreen+64000;lscreen++)
	  {
	     checkx=x+this->xoff[y];
	     checky=y+this->yoff[x];
	     if((checkx>0)&&(checkx<320) &&(checky>0)&&(checky<200))
		*lscreen=*(this->lbuffer+this->xoff[y]+320*this->yoff[x]);
	     else 
		*lscreen=0; 
	     this->lbuffer++;
	     x++;
	     if(x==320){x=0;y++;}
	  }
     }

void fudge(int argc, char **argv)
{
    #include "palette.fudge"
    int i;
    char t;
    struct vars this;
    char SIN[256];
    char COS[256];   
	vga_setmode(G320x200x256);
	signals();
	this.rscreen=vga_getgraphmem();
	for(i=0;i<255*3;i++)pal[i]>>=2;
	vga_setpalvec(0,256,pal);
t=0;
for(i=0;i<256;i++)
	{
	SIN[i]=sin((float)(3.1459*2*((float)i)/256))*127;
	COS[i]=cos((float)(3.1459*2*((float)i)/256))*127;
	}

   while(1)
     {
	for(i=0;i<320;i++)

		{
		this.yoff[i]=SIN[(unsigned char)((i*COS[(unsigned char)(t)]/128)+t)]/4;
		}
	for(i=0;i<200;i++)
		{
		this.xoff[i]=COS[(unsigned char)((i*SIN[(unsigned char)(t)]/64)+3*t)]/5;
		}
	draw_fudge(&this);
	if(vga_getkey()!=0 && vga_getkey()!=-1)authenticate();
	vga_waitretrace();  
	t++;
     }
}

